@@ -14,10 +14,13 @@ limitations under the License.
 package commands
 
 import (
+	"encoding/json"
 	"errors"
 	"strings"
 
 	"github.com/digitalocean/doctl"
+	"github.com/digitalocean/doctl/commands/displayers"
+	"github.com/digitalocean/doctl/do"
 	"github.com/spf13/cobra"
 )
 
@@ -26,17 +29,17 @@ func Functions() *Command {
 	cmd := &Command{
 		Command: &cobra.Command{
 			Use:   "functions",
-			Short: "Work with the functions of your sandbox",
-			Long: `The subcommands of ` + "`" + `doctl sandbox functions` + "`" + ` operate on the deployed (cloud-resident) functions of your sandbox.
+			Short: "Work with the functions in your namespace",
+			Long: `The subcommands of ` + "`" + `doctl serverless functions` + "`" + ` operate on your functions namespace. 
 You are able to inspect and list these functions to know what is deployed.  You can also invoke functions to test them.`,
 			Aliases: []string{"fn"},
 		},
 	}
 
 	get := CmdBuilder(cmd, RunFunctionsGet, "get <functionName>", "Retrieves the deployed copy of a function (code or metadata)",
-		`Use `+"`"+`doctl sandbox functions get`+"`"+` to obtain the code or metadata of a deployed function.
+		`Use `+"`"+`doctl serverless functions get`+"`"+` to obtain the code or metadata of a deployed function.
 This allows you to inspect the deployed copy and ascertain whether it corresponds to what
-is in your sandbox area in the local file system.`,
+is in your functions project in the local file system.`,
 		Writer)
 	AddBoolFlag(get, "url", "r", false, "get function url")
 	AddBoolFlag(get, "code", "", false, "show function code (only works if code is not a zip file)")
@@ -46,8 +49,8 @@ is in your sandbox area in the local file system.`,
 	AddStringFlag(get, "save-as", "", "", "file to save function code to")
 
 	invoke := CmdBuilder(cmd, RunFunctionsInvoke, "invoke <functionName>", "Invokes a function",
-		`Use `+"`"+`doctl sandbox functions invoke`+"`"+` to invoke a function of your sandbox that has been deployed
-to the cloud.  You can provide inputs and inspect outputs.`,
+		`Use `+"`"+`doctl serverless functions invoke`+"`"+` to invoke a function in your functions namespace.
+You can provide inputs and inspect outputs.`,
 		Writer)
 	AddBoolFlag(invoke, "web", "", false, "Invoke as a web function, show result as web page")
 	AddStringSliceFlag(invoke, "param", "p", []string{}, "parameter values in KEY:VALUE format, list allowed")
@@ -55,10 +58,9 @@ to the cloud.  You can provide inputs and inspect outputs.`,
 	AddBoolFlag(invoke, "full", "f", false, "wait for full activation record")
 	AddBoolFlag(invoke, "no-wait", "n", false, "fire and forget (asynchronous invoke, does not wait for the result)")
 
-	list := CmdBuilder(cmd, RunFunctionsList, "list [<packageName>]", "Lists all the functions",
-		`Use `+"`"+`doctl sandbox functions list`+"`"+` to list the functions of your sandbox that are deployed
-to the cloud.`,
-		Writer)
+	list := CmdBuilder(cmd, RunFunctionsList, "list [<packageName>]", "Lists the functions in your functions namespace",
+		`Use `+"`"+`doctl serverless functions list`+"`"+` to list the functions in your functions namespace.`,
+		Writer, displayerType(&displayers.Functions{}))
 	AddStringFlag(list, "limit", "l", "", "only return LIMIT number of functions (default 30, max 200)")
 	AddStringFlag(list, "skip", "s", "", "exclude the first SKIP number of functions from the result")
 	AddBoolFlag(list, "count", "", false, "show only the total number of functions")
@@ -108,11 +110,34 @@ func RunFunctionsList(c *CmdConfig) error {
 	if argCount > 1 {
 		return doctl.NewTooManyArgsErr(c.NS)
 	}
-	output, err := RunSandboxExec(actionList, c, []string{flagCount, flagNameSort, flagNameName}, []string{flagLimit, flagSkip})
+	// Determine if '--count' is requested since we will use simple text output in that case.
+	// Count is mutually exclusive with the global format flag.
+	count, _ := c.Doit.GetBool(c.NS, flagCount)
+	if count && c.Doit.IsSet("format") {
+		return errors.New("the --count and --format flags are mutually exclusive")
+	}
+	// Add JSON flag so we can control output format
+	if !count {
+		c.Doit.Set(c.NS, flagJSON, true)
+	}
+	output, err := RunSandboxExec(actionList, c, []string{flagCount, flagNameSort, flagNameName, flagJSON}, []string{flagLimit, flagSkip})
 	if err != nil {
 		return err
 	}
-	return c.PrintSandboxTextOutput(output)
+	if count {
+		return c.PrintSandboxTextOutput(output)
+	}
+	// Reparse the output to use a more specific type, which can then be passed to the displayer
+	rawOutput, err := json.Marshal(output.Entity)
+	if err != nil {
+		return err
+	}
+	var formatted []do.FunctionInfo
+	err = json.Unmarshal(rawOutput, &formatted)
+	if err != nil {
+		return err
+	}
+	return c.Display(&displayers.Functions{Info: formatted})
 }
 
 // appendParams determines if there is a 'param' flag (value is a slice, elements
