@@ -21,16 +21,23 @@ import (
 	"net/http"
 	"os"
 	"os/exec"
+	"path/filepath"
 	"strings"
 
 	"github.com/digitalocean/godo"
 )
 
-// SandboxCredentials is the type returned by the GetSandboxNamespace function.
-// The values in it can be used to connect sandbox support to a specific namespace using the plugin.
+// SandboxCredentials models what is stored in credentials.json for use by the plugin and nim.
+// It is also the type returned by the GetSandboxNamespace function.
 type SandboxCredentials struct {
-	Auth    string
-	APIHost string
+	APIHost     string                                  `json:"currentHost"`
+	Namespace   string                                  `json:"currentNamespace"`
+	Credentials map[string]map[string]SandboxCredential `json:"credentials"`
+}
+
+// SandboxCredential is the type of an individual entry in SandboxCredentials
+type SandboxCredential struct {
+	Auth string `json:"api_key"`
 }
 
 // The type of the "namespace" member of the response to /api/v2/functions/sandbox
@@ -63,6 +70,25 @@ type ServerlessHostInfo struct {
 	Runtimes map[string][]ServerlessRuntime `json:"runtimes"`
 }
 
+// FunctionInfo is the type of an individual function in the output
+// of doctl sls fn list.  Only relevant fields are unmarshaled.
+// Note: when we start replacing the sandbox plugin path with direct calls
+// to backend controller operations, this will be replaced by declarations
+// in the golang openwhisk client.
+type FunctionInfo struct {
+	Name        string       `json:"name"`
+	Namespace   string       `json:"namespace"`
+	Updated     int64        `json:"updated"`
+	Version     string       `json:"version"`
+	Annotations []Annotation `json:"annotations"`
+}
+
+// Annotation is a key/value type suitable for individual annotations
+type Annotation struct {
+	Key   string      `json:"key"`
+	Value interface{} `json:"value"`
+}
+
 // SandboxService is an interface for interacting with the sandbox plugin,
 // with the namespaces service, and with the serverless cluster controller.
 type SandboxService interface {
@@ -70,16 +96,21 @@ type SandboxService interface {
 	Exec(*exec.Cmd) (SandboxOutput, error)
 	Stream(*exec.Cmd) error
 	GetSandboxNamespace(context.Context) (SandboxCredentials, error)
+	WriteCredentials(SandboxCredentials) error
 	GetHostInfo(string) (ServerlessHostInfo, error)
 }
 
 type sandboxService struct {
-	sandboxJs  string
-	sandboxDir string
-	node       string
-	client     *godo.Client
+	sandboxJs string
+	credsDir  string // note: this was misleadingly named sandboxDir previously
+	node      string
+	userAgent string
+	client    *godo.Client
 }
 
+// CredentialsFile is the name of the file where the sandbox plugin stores OpenWhisk credentials.
+const CredentialsFile = "credentials.json"
+
 var _ SandboxService = &sandboxService{}
 
 // SandboxOutput contains the output returned from calls to the sandbox plugin.
@@ -92,12 +123,13 @@ type SandboxOutput struct {
 }
 
 // NewSandboxService returns a configured SandboxService.
-func NewSandboxService(sandboxJs string, sandboxDir string, node string, client *godo.Client) SandboxService {
+func NewSandboxService(sandboxJs string, credsDir string, node string, userAgent string, client *godo.Client) SandboxService {
 	return &sandboxService{
-		sandboxJs:  sandboxJs,
-		sandboxDir: sandboxDir,
-		node:       node,
-		client:     client,
+		sandboxJs: sandboxJs,
+		credsDir:  credsDir,
+		node:      node,
+		userAgent: userAgent,
+		client:    client,
 	}
 }
 
@@ -105,7 +137,7 @@ func NewSandboxService(sandboxJs string, sandboxDir string, node string, client
 func (n *sandboxService) Cmd(command string, args []string) (*exec.Cmd, error) {
 	args = append([]string{n.sandboxJs, command}, args...)
 	cmd := exec.Command(n.node, args...)
-	cmd.Env = append(os.Environ(), "NIMBELLA_DIR="+n.sandboxDir)
+	cmd.Env = append(os.Environ(), "NIMBELLA_DIR="+n.credsDir, "NIM_USER_AGENT="+n.userAgent)
 	// If DEBUG is specified, we need to open up stderr for that stream.  The stdout stream
 	// will continue to work for returning structured results.
 	if os.Getenv("DEBUG") != "" {
@@ -161,9 +193,13 @@ func (n *sandboxService) GetSandboxNamespace(ctx context.Context) (SandboxCreden
 	if err != nil {
 		return SandboxCredentials{}, err
 	}
+	host := assignAPIHost(decoded.Namespace.APIHost, decoded.Namespace.Namespace)
+	credential := SandboxCredential{Auth: decoded.Namespace.UUID + ":" + decoded.Namespace.Key}
+	namespace := decoded.Namespace.Namespace
 	ans := SandboxCredentials{
-		APIHost: assignAPIHost(decoded.Namespace.APIHost, decoded.Namespace.Namespace),
-		Auth:    decoded.Namespace.UUID + ":" + decoded.Namespace.Key,
+		APIHost:     host,
+		Namespace:   namespace,
+		Credentials: map[string]map[string]SandboxCredential{host: {namespace: credential}},
 	}
 	return ans, nil
 }
@@ -199,3 +235,19 @@ func assignAPIHost(origAPIHost string, namespace string) string {
 	}
 	return origAPIHost
 }
+
+// WriteCredentials writes a set of serverless credentials to the appropriate 'creds' directory
+func (n *sandboxService) WriteCredentials(creds SandboxCredentials) error {
+	// Create the directory into which the file will be written.
+	err := os.MkdirAll(n.credsDir, 0700)
+	if err != nil {
+		return err
+	}
+	// Write the credentials
+	credsPath := filepath.Join(n.credsDir, CredentialsFile)
+	bytes, err := json.MarshalIndent(&creds, "", "  ")
+	if err != nil {
+		return err
+	}
+	return os.WriteFile(credsPath, bytes, 0600)
+}
