@@ -20,8 +20,6 @@ mockgen -source domains.go -package=mocks DomainService > mocks/DomainService.go
 mockgen -source droplet_actions.go -package=mocks DropletActionsService > mocks/DropletActionService.go
 mockgen -source droplets.go -package=mocks DropletsService > mocks/DropletsService.go
 mockgen -source firewalls.go -package=mocks FirewallsService > mocks/FirewallsService.go
-mockgen -source floating_ip_actions.go -package=mocks FloatingIPActionsService > mocks/FloatingIPActionsService.go
-mockgen -source floating_ips.go -package=mocks FloatingIPsService > mocks/FloatingIPsService.go
 mockgen -source image_actions.go -package=mocks ImageActionsService > mocks/ImageActionsService.go
 mockgen -source images.go -package=mocks ImageService > mocks/ImageService.go
 mockgen -source invoices.go -package=mocks InvoicesService > mocks/InvoicesService.go
@@ -41,4 +39,6 @@ mockgen -source 1_clicks.go -package=mocks OneClickService > mocks/OneClickServi
 mockgen -source ../pkg/runner/runner.go -package=mocks Runner > mocks/Runner.go
 mockgen -source ../pkg/listen/listen.go -package=mocks Listen > mocks/Listen.go
 mockgen -source monitoring.go -package=mocks MonitoringService > mocks/MonitoringService.go
+mockgen -source reserved_ip_actions.go -package=mocks ReservedIPActionsService > mocks/ReservedIPActionsService.go
+mockgen -source reserved_ips.go -package=mocks ReservedIPsService > mocks/ReservedIPsService.go
 mockgen -source sandbox.go -package=mocks SandboxService > mocks/SandboxService.go
\ No newline at end of file
